@@ -36,8 +36,6 @@ class ShellTest(testtools.TestCase):
     FAKE_ENV = {
         'OS_USERNAME': DEFAULT_USERNAME,
         'OS_PASSWORD': DEFAULT_PASSWORD,
-        'OS_TENANT_ID': DEFAULT_PROJECT_ID,
-        'OS_TENANT_NAME': DEFAULT_PROJECT_NAME,
         'OS_PROJECT_ID': DEFAULT_PROJECT_ID,
         'OS_PROJECT_NAME': DEFAULT_PROJECT_NAME,
         'OS_AUTH_URL': DEFAULT_AUTH_URL,
